@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2018 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """ZeroMQ interface class."""
 
@@ -38,18 +28,16 @@ class Export(GlancesExport):
         """Init the ZeroMQ export IF."""
         super(Export, self).__init__(config=config, args=args)
 
-        # Mandatories configuration keys (additional to host and port)
+        # Mandatory configuration keys (additional to host and port)
         self.prefix = None
 
         # Optionals configuration keys
         # N/A
 
         # Load the ZeroMQ configuration file section ([export_zeromq])
-        self.export_enable = self.load_conf('zeromq',
-                                            mandatories=['host', 'port', 'prefix'],
-                                            options=[])
+        self.export_enable = self.load_conf('zeromq', mandatories=['host', 'port', 'prefix'], options=[])
         if not self.export_enable:
-            sys.exit(2)
+            exit('Missing ZEROMQ config')
 
         # Init the ZeroMQ context
         self.context = None
@@ -96,9 +84,7 @@ class Export(GlancesExport):
         # - First frame containing the following prefix (STRING)
         # - Second frame with the Glances plugin name (STRING)
         # - Third frame with the Glances plugin stats (JSON)
-        message = [b(self.prefix),
-                   b(name),
-                   asbytes(json.dumps(data))]
+        message = [b(self.prefix), b(name), asbytes(json.dumps(data))]
 
         # Write data to the ZeroMQ bus
         # Result can be view: tcp://host:port
