@@ -123,13 +123,10 @@ Examples of use:
             '--disable-plugin',
             '--disable-plugins',
             dest='disable_plugin',
-            help='disable plugin (comma separed list or all). If all is used, then you need to configure --enable-plugin.',
+            help='disable plugin (comma separated list or all). If all is used, then you need to configure --enable-plugin.',
         )
         parser.add_argument(
-            '--enable-plugin',
-            '--enable-plugins',
-            dest='enable_plugin',
-            help='enable plugin (comma separed list)'
+            '--enable-plugin', '--enable-plugins', dest='enable_plugin', help='enable plugin (comma separated list)'
         )
         parser.add_argument(
             '--disable-process',
@@ -256,7 +253,7 @@ Examples of use:
             help='Accumulate processes by program',
         )
         # Export modules feature
-        parser.add_argument('--export', dest='export', help='enable export module (comma separed list)')
+        parser.add_argument('--export', dest='export', help='enable export module (comma separated list)')
         parser.add_argument(
             '--export-csv-file', default='./glances.csv', dest='export_csv_file', help='file path for CSV exporter'
         )
@@ -567,7 +564,9 @@ Examples of use:
                 logger.critical("'all' key in --disable-plugin needs to be used with --enable-plugin")
                 sys.exit(2)
             else:
-                logger.info("'all' key in --disable-plugin, only plugins defined with --enable-plugin will be available")
+                logger.info(
+                    "'all' key in --disable-plugin, only plugins defined with --enable-plugin will be available"
+                )
         if args.disable_plugin is not None:
             for p in args.disable_plugin.split(','):
                 disable(args, p)
