@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2018 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """Manage the Glances server."""
 
@@ -25,7 +15,7 @@ import sys
 from base64 import b64decode
 
 from glances import __version__
-from glances.compat import SimpleXMLRPCRequestHandler, SimpleXMLRPCServer, Server
+from glances.compat import SimpleXMLRPCRequestHandler, SimpleXMLRPCServer
 from glances.autodiscover import GlancesAutoDiscoverClient
 from glances.logger import logger
 from glances.stats_server import GlancesStatsServer
@@ -36,7 +26,7 @@ class GlancesXMLRPCHandler(SimpleXMLRPCRequestHandler, object):
 
     """Main XML-RPC handler."""
 
-    rpc_paths = ('/RPC2', )
+    rpc_paths = ('/RPC2',)
 
     def end_headers(self):
         # Hack to add a specific header
@@ -53,7 +43,7 @@ class GlancesXMLRPCHandler(SimpleXMLRPCRequestHandler, object):
         try:
             (basic, _, encoded) = headers.get('Authorization').partition(' ')
         except Exception:
-            # Client did not ask for authentidaction
+            # Client did not ask for authentication
             # If server need it then exit
             return not self.server.isAuth
         else:
@@ -61,7 +51,7 @@ class GlancesXMLRPCHandler(SimpleXMLRPCRequestHandler, object):
             (basic, _, encoded) = headers.get('Authorization').partition(' ')
             assert basic == 'Basic', 'Only basic authentication supported'
             # Encoded portion of the header is a string
-            # Need to convert to bytestring
+            # Need to convert to byte-string
             encoded_byte_string = encoded.encode()
             # Decode base64 byte string to a decoded byte string
             decoded_bytes = b64decode(encoded_byte_string)
@@ -76,6 +66,7 @@ class GlancesXMLRPCHandler(SimpleXMLRPCRequestHandler, object):
         # Check username and password in the dictionary
         if username in self.server.user_dict:
             from glances.password import GlancesPassword
+
             pwd = GlancesPassword()
             return pwd.check_password(self.server.user_dict[username], password)
         else:
@@ -102,8 +93,7 @@ class GlancesXMLRPCServer(SimpleXMLRPCServer, object):
 
     finished = False
 
-    def __init__(self, bind_address, bind_port=61209,
-                 requestHandler=GlancesXMLRPCHandler):
+    def __init__(self, bind_address, bind_port=61209, requestHandler=GlancesXMLRPCHandler):
 
         self.bind_address = bind_address
         self.bind_port = bind_port
@@ -130,9 +120,7 @@ class GlancesInstance(object):
 
     """All the methods of this class are published as XML-RPC methods."""
 
-    def __init__(self,
-                 config=None,
-                 args=None):
+    def __init__(self, config=None, args=None):
         # Init stats
         self.stats = GlancesStatsServer(config=config, args=args)
 
@@ -197,10 +185,7 @@ class GlancesServer(object):
 
     """This class creates and manages the TCP server."""
 
-    def __init__(self,
-                 requestHandler=GlancesXMLRPCHandler,
-                 config=None,
-                 args=None):
+    def __init__(self, requestHandler=GlancesXMLRPCHandler, config=None, args=None):
         # Args
         self.args = args
 
