@@ -2,20 +2,10 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """Manage the Glances standalone session."""
 
@@ -24,12 +14,15 @@ import time
 
 from glances.globals import WINDOWS
 from glances.logger import logger
+from glances.outputs.glances_stdout_json import GlancesStdoutJson
 from glances.processes import glances_processes
 from glances.stats import GlancesStats
 from glances.outputs.glances_curses import GlancesCursesStandalone
 from glances.outputs.glances_stdout import GlancesStdout
+from glances.outputs.glances_stdout_json import GlancesStdoutJson
 from glances.outputs.glances_stdout_csv import GlancesStdoutCsv
 from glances.outputs.glances_stdout_issue import GlancesStdoutIssue
+from glances.outputs.glances_stdout_apidoc import GlancesStdoutApiDoc
 from glances.outdated import Outdated
 from glances.timer import Counter
 
@@ -66,7 +59,7 @@ class GlancesStandalone(object):
             logger.debug("Extended stats for top process are enabled")
             glances_processes.enable_extended()
 
-        # Manage optionnal process filter
+        # Manage optional process filter
         if args.process_filter is not None:
             glances_processes.process_filter = args.process_filter
 
@@ -74,7 +67,7 @@ class GlancesStandalone(object):
             # Ignore kernel threads in process list
             glances_processes.disable_kernel_threads()
 
-        # Initial system informations update
+        # Initial system information update
         start_duration.reset()
         self.stats.update()
         logger.debug("First stats update duration: {} seconds".format(start_duration.get()))
@@ -87,10 +80,18 @@ class GlancesStandalone(object):
             logger.info("Issue mode is ON")
             # Init screen
             self.screen = GlancesStdoutIssue(config=config, args=args)
+        elif args.stdout_apidoc:
+            logger.info("Fields descriptions mode is ON")
+            # Init screen
+            self.screen = GlancesStdoutApiDoc(config=config, args=args)
         elif args.stdout:
             logger.info("Stdout mode is ON, following stats will be displayed: {}".format(args.stdout))
             # Init screen
             self.screen = GlancesStdout(config=config, args=args)
+        elif args.stdout_json:
+            logger.info("Stdout JSON mode is ON, following stats will be displayed: {}".format(args.stdout_json))
+            # Init screen
+            self.screen = GlancesStdoutJson(config=config, args=args)
         elif args.stdout_csv:
             logger.info("Stdout CSV mode is ON, following stats will be displayed: {}".format(args.stdout_csv))
             # Init screen
@@ -111,14 +112,13 @@ class GlancesStandalone(object):
 
     def display_modules_list(self):
         """Display modules list"""
-        print("Plugins list: {}".format(
-            ', '.join(sorted(self.stats.getPluginsList(enable=False)))))
-        print("Exporters list: {}".format(
-            ', '.join(sorted(self.stats.getExportsList(enable=False)))))
+        print("Plugins list: {}".format(', '.join(sorted(self.stats.getPluginsList(enable=False)))))
+        print("Exporters list: {}".format(', '.join(sorted(self.stats.getExportsList(enable=False)))))
 
     def serve_issue(self):
         """Special mode for the --issue option
-        Update is done in the sceen.update function
+
+        Update is done in the screen.update function
         """
         ret = not self.screen.update(self.stats)
         self.end()
@@ -127,7 +127,7 @@ class GlancesStandalone(object):
     def __serve_once(self):
         """Main loop for the CLI.
 
-        return True if we should continue (no exit key has been pressed)
+        :return: True if we should continue (no exit key has been pressed)
         """
         # Update stats
         # Start a counter used to compute the time needed
@@ -150,8 +150,7 @@ class GlancesStandalone(object):
         if not self.quiet:
             # The update function return True if an exit key 'q' or 'ESC'
             # has been pressed.
-            ret = not self.screen.update(self.stats,
-                                         duration=adapted_refresh)
+            ret = not self.screen.update(self.stats, duration=adapted_refresh)
         else:
             # Nothing is displayed
             # Break should be done via a signal (CTRL-C)
@@ -162,12 +161,21 @@ class GlancesStandalone(object):
 
     def serve_forever(self):
         """Wrapper to the serve_forever function."""
-        # loop = True
-        # while loop:
-        #     loop = self.__serve_once()
-        while self.__serve_once():
-            pass
-        self.end()
+        if self.args.stop_after:
+            for _ in range(self.args.stop_after):
+                if not self.__serve_once():
+                    break
+        else:
+            while self.__serve_once():
+                pass
+        # self.end()
+
+    def serve_n(self, n=1):
+        """Serve n time."""
+        for _ in range(n):
+            if not self.__serve_once():
+                break
+        # self.end()
 
     def end(self):
         """End of the standalone CLI."""
@@ -179,6 +187,9 @@ class GlancesStandalone(object):
 
         # Check Glances version versus PyPI one
         if self.outdated.is_outdated():
-            print("You are using Glances version {}, however version {} is available.".format(
-                self.outdated.installed_version(), self.outdated.latest_version()))
+            print(
+                "You are using Glances version {}, however version {} is available.".format(
+                    self.outdated.installed_version(), self.outdated.latest_version()
+                )
+            )
             print("You should consider upgrading using: pip install --upgrade glances")
